@@ -281,10 +281,9 @@ def _bsd_cpudata(osdata):
 
     grains = dict([(k, __salt__['cmd.run'](v)) for k, v in cmds.items()])
 
-    if grains['cpu_flags'] and not isinstance(grains['cpu_flags'], list):
+    if 'cpu_flags' in grains and isinstance(grains['cpu_flags'], basestring):
         grains['cpu_flags'] = grains['cpu_flags'].split(' ')
 
-
     if osdata['kernel'] == 'NetBSD':
         grains['cpu_flags'] = []
         for line in __salt__['cmd.run']('cpuctl identify 0').splitlines():
@@ -884,6 +883,8 @@ def os_data():
     # Load the virtual machine info
     grains.update(_virtual(grains))
     grains.update(_ps(grains))
+    if grains['os_family'] == "RedHat":
+        grains['osmajorrelease'] = grains['osrelease'].split('.', 1)
 
     return grains
 
