@@ -2,6 +2,16 @@
 Manage groups on FreeBSD
 '''
 
+# Import python libs
+import logging
+
+# Import salt libs
+import salt.utils
+
+
+log = logging.getLogger(__name__)
+
+
 try:
     import grp
 except ImportError:
@@ -15,7 +25,7 @@ def __virtual__():
     return 'group' if __grains__['kernel'] == 'FreeBSD' else False
 
 
-def add(name, gid=None, system=False):
+def add(name, gid=None, **kwargs):
     '''
     Add the specified group
 
@@ -23,6 +33,11 @@ def add(name, gid=None, system=False):
 
         salt '*' group.add foo 3456
     '''
+    if salt.utils.is_true(kwargs.pop('system', False)):
+        log.warning('pw_group module does not support the \'system\' argument')
+    if kwargs:
+        raise TypeError('Invalid keyword argument(s): {}'.format(kwargs))
+
     cmd = 'pw groupadd '
     if gid:
         cmd += '-g {0} '.format(gid)
