@@ -162,7 +162,7 @@ class OptionParser(optparse.OptionParser):
                 )
 
         if self.config.get('conf_file', None) is not None:
-            logging.getLogger(__name__).info(
+            logging.getLogger(__name__).debug(
                 'Configuration file path: {0}'.format(
                     self.config['conf_file']
                 )
