@@ -31,6 +31,11 @@ class SysctlModuleTest(integration.ModuleCase):
                            1,
                            'Multiline value was parsed wrong')
 
+    @skipIf(not sys.platform.startswith('darwin'), 'Darwin (OS X) specific')
+    def test_show_darwin(self):
+        ret = self.run_function('sysctl.show')
+        self.assertIn('kern.ostype', ret, 'kern.ostype absent')
+        self.assertEqual(ret.get('kern.ostype'), 'Darwin', 'Incorrect kern.ostype')
 
 if __name__ == '__main__':
     from integration import run_tests
